import { BigIntish } from './types';
/**
 * Converts an amount. The conversion rate is expressed as the amount of the output token
 * obtained per unit of the input token.
 *
 * e.g:
 * Input token: ANT
 * Output token: ETH
 * Amount of ANT: 10
 * Conversion rate: 0.5 ETH per ANT. (1 ANT = 0.5 ETH)
 * Converted Amount = 10 * 0.50 = 5 ETH.
 *
 * @param {BigInt|string|number} amount              Amount of the input token to convert.
 * @param {BigInt|string|number} decimals            Decimals of the input token to convert.
 * @param {string|number} convertRate                Rate of conversion between the input and output token.
 * @param {BigInt|string|number} targetDecimals      Decimals for the output amount.
 * @returns {string}
 */
export declare function convertAmount(amount: BigIntish, decimals: BigIntish, convertRate: string | number, targetDecimals: BigIntish): string;
